{% load i18n %}

<div class="content-wrapper">
<div class="container">
<div class="row">
<div class="col-xs-12 col-xs-offset-0 col-md-6 col-md-offset-3 col-sm-10 col-sm-offset-1">

<div id="mc_embed_signup">
	<form action="{{post_url}}?u={{user_id}}&amp;id={{list_id}}" method="post" id="mc-embedded-subscribe-form-{{form_id}}" name="mc-embedded-subscribe-form-{{form_id}}" class="validate mc-client" target="_blank" novalidate>
	<div id="mc_embed_signup_scroll">
		<div class="mc-field-group form-group form-required">
			<p for='mce-EMAIL'>{{description|linebreaks}}</p>
			<input type="email" value="{{email|default_if_none:''}}" name="EMAIL" class="form-control required email" id="mce-EMAIL" placeholder="{{placeholder}}">
		</div>

		<div id="mce-responses" class="clear">
			<div class="response" id="mce-error-response" style="display:none"></div>
			<div class="response" id="mce-success-response" style="display:none"></div>
    </div> {# real people should not fill this in and expect good things - do not remove this or risk form bot signups #}

		<div style="position: absolute; left: -5000px;" aria-hidden="true"><input type="text" name="b_{{user_id}}_{{list_id}}" tabindex="-1" value=""></div>
			<div class="clear">
        <input type="submit" value="{% trans 'Subscribe' %}"name="subscribe" id="mc-embedded-subscribe" class="btn btn-success">
			</div>
		</div>
	</form>
	<script>
	$("#mc-embedded-subscribe-form-{{form_id}}").validate();
	</script>
</div>

</div>
</div>
</div>
</div>
